pub fn connect_request(db_handle: u32) -> BytesExpand description
Auxiliary channel request.
Firebird does not push the event notifications on the connection that registered them: it asks the client to open a second, “async” connection and answers this request with the address it listens on for it.